// Problem: Equal Is Not Really Equal
// Author: Rudy van Vliet
// Date: 17 August 2010

// Solution works directly on the string
// Time complexity: at least O(N^3) in the worst case,
// where N is the length of the string

#include <iostream>
#include <cstring>
using namespace std;

const int MaxLength = 10000;  // maximum length of string

//****************************************************************************

int FirstCheck (char *str)
 // return: 0, if we can conclude already that str is unique
 //           (if all characters in str are equal)
 //         1, if we can conclude already that str is not unique
 //           (if str contains at least two different characters,
 //            and the first character of str equals the last character)
 //         2, otherwise
 // function is derived from function CountNrArcs in faster solution
 // of Equal $\neq$ equal
{ int i, j,
      length, pos;
  bool differentcharacters;
  char firstchar;

  firstchar = str[0];
  differentcharacters = false; // we have not seen different characters, yet

  length = strlen (str);
  i = (int) firstchar;
  for (pos=1;pos<=length-1;pos++)
  { if (str[pos] != firstchar)
      differentcharacters = true;
    j = (int) str[pos];
    i = j;
  }

  if (!differentcharacters)  // all characters are equal, hence unique
    return 0;
  else  // different characters
    if (str[0]==str[length-1])  // first character equals last character,
      return 1;                // hence not unique
  else
    return 2;  // not yet determined: maybe unique, maybe not unique

}  // FirstCheck

//****************************************************************************

bool CheckUnique (char *str)
 // pre: str contains at least two different characters,
 //      and first character of str is not equal to last character
{ int length,
      posA1, posA2,
      posC1, posC2;
  bool unique;

  unique = true;
  length = strlen (str);

  for (posA1=0;(posA1<=length-3)&&unique;posA1++)
    for (posA2=posA1+1;(posA2<=length-2)&&unique;posA2++)
      if (str[posA1] == str[posA2])  // equal letters
      { if (str[posA1+1] != str[posA2+1])  // followed by unequal letters
        { for (posC1=posA1+1;(posC1<=posA2)&&unique;posC1++)
            for (posC2=posA2+1;(posC2<=length-1)&&unique;posC2++)
              if (str[posC1] == str[posC2])
                // We can exchange the substrings
                // str[posA1+1..posC1-1] and str[posA2+1..posC2-1],
                // because both are preceded by A and followed by C.
                // Note that at least one of these two substrings is non-empty,
                // because  str[posA1+1] != str[posA2+1].
                unique = false;
        }
      }

  return unique;

}  // CheckUnique

//****************************************************************************

int main ()
{ int NInst, Inst;
  char OrigString[MaxLength+1];
  int code;

  cin >> NInst;
  for (Inst=1;Inst<=NInst;Inst++)
  { cin >> OrigString;  // does not work for strings containing spaces, ...

    code = FirstCheck (OrigString);
    if (code == 0)
      cout << "unique\n";
    else
      if (code == 1)
        cout << "not unique\n";
      else  // code == 2
      { if (CheckUnique (OrigString))
          cout << "unique\n";
        else
          cout << "not unique\n";
      }


  }  // for Inst
  
  return 0;

}
