
//
// Walter Kosters, September 9, 2010: Farmer John
//

#include <iostream>
#include <cmath>
using namespace std;

const int MAXPOINTS = 400;
const int INFTY = 2000000000;
const double eps = 0.0;

int Px[MAXPOINTS];
int Py[MAXPOINTS];
int N;

double Dijkstra[MAXPOINTS][MAXPOINTS];

// return true if a-b and u-v really cross
bool crossing (int a1, int a2, int b1, int b2, 
               int u1, int u2, int v1, int v2) { 
  int R = (a1-u1)*(b2-a2) - (a2-u2)*(b1-a1);
  int S = (a1-u1)*(v2-u2) - (a2-u2)*(v1-u1);
  int T = (v1-u1)*(b2-a2) - (v2-u2)*(b1-a1);
  if ( T == 0 ) return false;
  double one = (double)R/T;
  double two = (double)S/T;
  return ( 0.0 + eps < one && one < 1.0 - eps 
           && 0.0 + eps < two && two < 1.0 - eps );
}//crossing

// compute straightline Euclidean distance between (a1,a2) and (b1,b2)
// make sure that there is no fence in between, otherwise INFTY
double distance (int a1, int a2, int b1, int b2) {
  int i;
  for ( i = 1; i < N+1; i++ )
    if ( crossing (a1,a2,b1,b2,Px[2*i],Py[2*i],Px[2*i+1],Py[2*i+1]) )
      return INFTY;
  return ( (a1-b1)*(a1-b1) + (a2-b2)*(a2-b2) );
}//distance

int main ( ) {
  int cases, casenr, i, j, index;
  bool visited[MAXPOINTS];
  double thedist[MAXPOINTS];
  double smallest;

  cin >> cases;
  for ( casenr = 0; casenr < cases; casenr++ ) {
    cin >> Px[0] >> Py[0] >> Px[1] >> Py[1];
    cin >> N;
    for ( i = 1; i < N+1; i++ )
      cin >> Px[2*i] >> Py[2*i] >> Px[2*i+1] >> Py[2*i+1]; 
    for ( i = 0; i < 2*N+2; i++ ) {
      Dijkstra[i][i] = 0.0;
      for ( j = i+1; j < 2*N+2; j++ )
        Dijkstra[i][j] = Dijkstra[j][i] 
	  = sqrt ( distance (Px[i],Py[i],Px[j],Py[j]) );
    }//for
    visited[0] = true;
    thedist[0] = 0.0;
    for ( i = 1; i < 2*N+2; i++ ) {
      visited[i] = false;
      thedist[i] = INFTY;
    }//for
    index = 100;
    while ( index != 1 && index != -1 ) {
      smallest = INFTY;
      index = -1;
      for ( i = 0; i < 2*N+2; i++ )
        if ( visited[i] ) {
          for ( j = 0; j < 2*N+2; j++ )
	    if ( !visited[j] && thedist[i]+Dijkstra[i][j] < smallest ) {
	      index = j;
	      smallest = thedist[i]+Dijkstra[i][j];
	    }//if
	}//if
      if ( smallest < INFTY-eps ) {
        visited[index] = true;
	thedist[index] = smallest;
      }//if
    }//while
    if ( index == 1 )
      printf ("%1.6f\n",smallest);
    else
      cout << "Problems ..." << endl;
  }//for

  return 0;
}//main

